.. _anomaly_detectors:

Anomaly detectors
=================

Base
----

.. currentmodule:: skchange.anomaly_detectors.base
.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    BaseSegmentAnomalyDetector

Segment anomaly detectors
----------------------------
.. currentmodule:: skchange.anomaly_detectors

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    CAPA
    CircularBinarySegmentation
    StatThresholdAnomaliser
